@@ -745,6 +745,6 @@ class PublicController extends AbstractFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/Controller/PublicController.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Controller/PublicController.php");
+        return new Source("", "@bundles/PageBundle/Controller/PublicController.php", "/var/www/html/production-demo/app/bundles/PageBundle/Controller/PublicController.php");
     }
 }
