@@ -238,6 +238,6 @@ class __TwigTemplate_b797fa2ef6c53d8cb6a2d81217727d04 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Helper/modal.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Helper/modal.html.twig");
+        return new Source("", "@MauticCore/Helper/modal.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Helper/modal.html.twig");
     }
 }
