@@ -625,6 +625,6 @@ class ReportSubscriber implements EventSubscriberInterface
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/EventListener/ReportSubscriber.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/EventListener/ReportSubscriber.php");
+        return new Source("", "@bundles/PageBundle/EventListener/ReportSubscriber.php", "/var/www/html/production-demo/app/bundles/PageBundle/EventListener/ReportSubscriber.php");
     }
 }
