@@ -497,6 +497,6 @@ Mautic.cloneReportRow = function (containerId) {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/ReportBundle/Assets/js/report.js", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Assets/js/report.js");
+        return new Source("", "@bundles/ReportBundle/Assets/js/report.js", "/var/www/html/production-demo/app/bundles/ReportBundle/Assets/js/report.js");
     }
 }
