@@ -889,6 +889,6 @@ class StatRepository extends CommonRepository
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Entity/StatRepository.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Entity/StatRepository.php");
+        return new Source("", "@bundles/EmailBundle/Entity/StatRepository.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Entity/StatRepository.php");
     }
 }
