@@ -1728,6 +1728,6 @@ body.outlook p {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@email/zurb_2/main.css", "/var/www/html/mauticGIT-Test/vendor/symfony/twig-bridge/Resources/views/Email/zurb_2/main.css");
+        return new Source("", "@email/zurb_2/main.css", "/var/www/html/production-demo/vendor/symfony/twig-bridge/Resources/views/Email/zurb_2/main.css");
     }
 }
