@@ -409,6 +409,6 @@ class __TwigTemplate_948dce21cf56e311bacc21e8c5d4b0ed extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/sunday/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/sunday/html/email.html.twig");
+        return new Source("", "@themes/sunday/html/email.html.twig", "/var/www/html/production-demo/themes/sunday/html/email.html.twig");
     }
 }
