@@ -252,6 +252,6 @@ R6UYYҽ+ix709?\"9S{yFў+!A՛LpmAC.\000i\000\000W~n1ߵ?4h1Mo.Q{#
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/paprika/assets/logo.jpg", "/var/www/html/mauticGIT-Test/themes/paprika/assets/logo.jpg");
+        return new Source("", "@themes/paprika/assets/logo.jpg", "/var/www/html/production-demo/themes/paprika/assets/logo.jpg");
     }
 }
