@@ -300,6 +300,6 @@ $context["item"], "model" => "user"]);
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticUser/User/list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/UserBundle/Resources/views/User/list.html.twig");
+        return new Source("", "@MauticUser/User/list.html.twig", "/var/www/html/production-demo/app/bundles/UserBundle/Resources/views/User/list.html.twig");
     }
 }
