@@ -363,6 +363,6 @@ class __TwigTemplate_6146af74998d604468897675a743438f extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/neopolitan/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/neopolitan/html/email.html.twig");
+        return new Source("", "@themes/neopolitan/html/email.html.twig", "/var/www/html/production-demo/themes/neopolitan/html/email.html.twig");
     }
 }
