@@ -542,6 +542,6 @@ mautic.email.send.dnc.confirmation.cancel.text=\"Cancel\"
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Translations/en_US/messages.ini");
+        return new Source("", "@bundles/EmailBundle/Translations/en_US/messages.ini", "/var/www/html/production-demo/app/bundles/EmailBundle/Translations/en_US/messages.ini");
     }
 }
