@@ -588,6 +588,6 @@ class __TwigTemplate_06e78638323096c76dc91fa5423cbc03 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/causebuzz-grapejs-suite/html/message.html.twig", "/var/www/html/mauticGIT-Test/themes/causebuzz-grapejs-suite/html/message.html.twig");
+        return new Source("", "@themes/causebuzz-grapejs-suite/html/message.html.twig", "/var/www/html/production-demo/themes/causebuzz-grapejs-suite/html/message.html.twig");
     }
 }
