@@ -578,6 +578,6 @@ class __TwigTemplate_170cf9edf84aca1755f561ef9a298eec extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/causebuzz-grapejs-suite/html/email.mjml.twig", "/var/www/html/mauticGIT-Test/themes/causebuzz-grapejs-suite/html/email.mjml.twig");
+        return new Source("", "@themes/causebuzz-grapejs-suite/html/email.mjml.twig", "/var/www/html/production-demo/themes/causebuzz-grapejs-suite/html/email.mjml.twig");
     }
 }
