@@ -546,6 +546,6 @@ q
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-fixed/css/open-sans/OpenSans-Bold.WOFF", "/var/www/html/mauticGIT-Test/themes/fresh-fixed/css/open-sans/OpenSans-Bold.WOFF");
+        return new Source("", "@themes/fresh-fixed/css/open-sans/OpenSans-Bold.WOFF", "/var/www/html/production-demo/themes/fresh-fixed/css/open-sans/OpenSans-Bold.WOFF");
     }
 }
