@@ -643,6 +643,6 @@ class CommonApiController extends FetchCommonApiController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/ApiBundle/Controller/CommonApiController.php", "/var/www/html/mauticGIT-Test/app/bundles/ApiBundle/Controller/CommonApiController.php");
+        return new Source("", "@bundles/ApiBundle/Controller/CommonApiController.php", "/var/www/html/production-demo/app/bundles/ApiBundle/Controller/CommonApiController.php");
     }
 }
