@@ -1151,6 +1151,6 @@ class Event implements ChannelInterface
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Entity/Event.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Entity/Event.php");
+        return new Source("", "@bundles/CampaignBundle/Entity/Event.php", "/var/www/html/production-demo/app/bundles/CampaignBundle/Entity/Event.php");
     }
 }
